``imbalanced_ensemble.metrics``
*********************************

This is the full API documentation of the `imbalanced_ensemble.metrics` module.

.. toctree::
   :maxdepth: 3

   classification
   pairwise
